herethere
=========

.. start-badges
.. image:: https://img.shields.io/pypi/v/herethere.svg
    :target: https://pypi.python.org/pypi/herethere
    :alt: Latest version on PyPi
.. image:: https://img.shields.io/pypi/pyversions/herethere.svg
    :target: https://pypi.python.org/pypi/herethere
    :alt: Supported Python versions
.. image:: https://github.com/b3b/herethere/workflows/ci/badge.svg?branch=master
     :target: https://github.com/b3b/herethere/actions?workflow=CI
     :alt: CI Status
.. image:: https://codecov.io/github/b3b/herethere/coverage.svg?branch=master
    :target: https://codecov.io/github/b3b/herethere?branch=master
    :alt: Code coverage Status
.. end-badges

Library for interactive code execution on a remote machine via SSH.
